@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-import sys,os,difflib,jinja2,re,json
+import sys,os,difflib,jinja2,re,json,datetime
 
 __all__=["db","ckd","dbdata","storidata","stdata"]
 
@@ -13,6 +13,18 @@ def quit(errinfo,exitcode=0):
     print(errinfo)
     sys.exit(exitcode)
 
+class ComplexEncoder(json.JSONEncoder):
+    def default(self, obj):
+        print(obj,type(obj))
+        if isinstance(obj, datetime.datetime):
+            return obj.strftime('%Y-%m-%d %H:%M:%S')
+        elif isinstance(obj, datetime.date):
+            return obj.strftime('%Y-%m-%d')
+        elif isinstance(obj,bytes):
+            return ""
+        else:
+            return json.JSONEncoder.default(self, obj)
+
 class dblib(object):
     def res1(self,ssql,*args,**kwargs):
         c=self.conn.cursor()
@@ -106,7 +118,7 @@ class render(object):
                 self.rendertable(t)
     def rendertable(self,t):
         if "help" in stdata and stdata["help"].lower() in ["y","1"]:
-            print(json.dumps(t,ensure_ascii=False,skipkeys=False,indent=4))
+            print(json.dumps(t,ensure_ascii=False,skipkeys=False,indent=4,cls=ComplexEncoder))
         tpl=""  #模板
         k=False
         for l in storidata:
